@@ -56,6 +56,7 @@
 #include <time.h>
 
 #include <glib/gstdio.h>
+#include <dbus/dbus-glib.h>  // dbus_g_thread_init
 
 #include "config.h"
 #include "cairo-dock-icon-facility.h"  // cairo_dock_get_first_icon
@@ -290,6 +291,16 @@ int main (int argc, char** argv)
 	if (getenv("TERM") == NULL)  /// why not isatty(stdout) ?...
 		g_set_print_handler(PrintMuteFunc);
 	
+	
+	// init lib
+	g_type_init (); // should initialise threads too on new versions of GLIB (>= 2.24)
+	#if (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 24)
+	if (!g_thread_supported ())
+		g_thread_init (NULL);
+	#endif
+
+	dbus_g_thread_init (); // it's a wrapper: it will use dbus_threads_init_default ();
+	
 	gtk_init (&argc, &argv);
 	
 	GError *erreur = NULL;
@@ -556,7 +567,6 @@ int main (int argc, char** argv)
 	//\___________________ load plug-ins (must be done after everything is initialized).
 	if (! bSafeMode)
 	{
-		GError *erreur = NULL;
 		cairo_dock_load_modules_in_directory (NULL, &erreur);  // load gldi-based plug-ins
 		if (erreur != NULL)
 		{
