@@ -78,10 +78,6 @@ typedef enum {
 	CAIRO_DOCK_WIDGET_VIEW_LIST='n',
 	/// list of themes in a combo, with preview and readme.
 	CAIRO_DOCK_WIDGET_THEME_LIST='h',
-	/// same but with a combo-entry to let the user enter any text.
-	CAIRO_DOCK_WIDGET_THEME_LIST_ENTRY='H',
-	/// list of dock themes, sortable by name, rating, and sobriety.
-	CAIRO_DOCK_WIDGET_THEME_SELECTOR='R',
 	/// list of available animations.
 	CAIRO_DOCK_WIDGET_ANIMATION_LIST='a',
 	/// list of available dialog decorators.
@@ -110,6 +106,8 @@ typedef enum {
 	CAIRO_DOCK_WIDGET_STRING_ENTRY='s',
 	/// a text entry with a file selector.
 	CAIRO_DOCK_WIDGET_FILE_SELECTOR='S',
+	/// a text entry with a file selector, files are filtered to only display images.
+	CAIRO_DOCK_WIDGET_IMAGE_SELECTOR='g',
 	/// a text entry with a folder selector.
 	CAIRO_DOCK_WIDGET_FOLDER_SELECTOR='D',
 	/// a text entry with a file selector and a 'play' button, for sound files.
@@ -142,6 +140,8 @@ typedef enum {
 	
 	/// an empty GtkContainer, in case you need to build custom widgets.
 	CAIRO_DOCK_WIDGET_EMPTY_WIDGET='_',
+	/// an empty GtkContainer, the same but using full available space.
+	CAIRO_DOCK_WIDGET_EMPTY_FULL='<',
 	/// a simple text label.
 	CAIRO_DOCK_WIDGET_TEXT_LABEL='>',
 	/// a simple text label.
@@ -209,25 +209,24 @@ void cairo_dock_free_generated_widget_list (GSList *pWidgetList);
  // utilities //
 ///////////////
 
+void cairo_dock_fill_model_with_themes (GtkListStore *pModel, GHashTable *pThemeTable, const gchar *cHint);
+
 void cairo_dock_fill_combo_with_list (GtkWidget *pCombo, GList *pElementList, const gchar *cActiveElement);  // utile pour les applets.
 
 GtkWidget *cairo_dock_gui_make_tree_view (gboolean bGetActiveOnly);
 
 GtkWidget *cairo_dock_gui_make_combo (gboolean bWithEntry);
 
-void cairo_dock_gui_select_in_combo (GtkWidget *pOneWidget, const gchar *cValue);
+void cairo_dock_gui_select_in_combo_full (GtkWidget *pOneWidget, const gchar *cValue, gboolean bIsTheme);
+#define cairo_dock_gui_select_in_combo(pOneWidget, cValue) cairo_dock_gui_select_in_combo_full (pOneWidget, cValue, FALSE)
 
 gchar **cairo_dock_gui_get_active_rows_in_tree_view (GtkWidget *pOneWidget, gboolean bSelectedRows, gsize *iNbElements);
 
-gchar *cairo_dock_gui_get_active_row_in_combo (GtkWidget *pOneWidget);
-
 
 CairoDockGroupKeyWidget *cairo_dock_gui_find_group_key_widget_in_list (GSList *pWidgetList, const gchar *cGroupName, const gchar *cKeyName);
 
-CairoDockGroupKeyWidget *cairo_dock_gui_find_group_key_widget (GtkWidget *pWindow, const gchar *cGroupName, const gchar *cKeyName);
-
 #define cairo_dock_gui_get_widgets(pGroupKeyWidget) (pGroupKeyWidget)->pSubWidgetList
-#define cairo_dock_gui_get_first_widget(pGroupKeyWidget) (pGroupKeyWidget)->pSubWidgetList->data
+#define cairo_dock_gui_get_first_widget(pGroupKeyWidget) ((pGroupKeyWidget)->pSubWidgetList ? (pGroupKeyWidget)->pSubWidgetList->data : NULL)
 #define cairo_dock_gui_add_widget(pGroupKeyWidget, pOneWidget) (pGroupKeyWidget)->pSubWidgetList = g_slist_append ((pGroupKeyWidget)->pSubWidgetList, pOneWidget)
 
 GtkWidget *_gtk_image_new_from_file (const gchar *cIcon, int iSize);
