@@ -24,7 +24,6 @@
 #include <gtk/gtk.h>
 
 
-
 #include "cairo-dock-draw.h"
 #include "cairo-dock-surface-factory.h"
 #include "cairo-dock-log.h"
@@ -135,7 +134,7 @@ void cairo_dock_load_image_buffer_full (CairoDockImageBuffer *pImage, const gcha
 			else if (w > 2 * h)  // if we're pretty sure this image is an animated one, try to be smart, to handle the case of non-square frames.
 			{
 				// assume we have wide frames => w > h
-				int w_ = h+1, h_ = h;
+				int w_ = h+1;
 				do
 				{
 					//g_print (" %d/%d\n", w_, (int)w);
@@ -149,6 +148,11 @@ void cairo_dock_load_image_buffer_full (CairoDockImageBuffer *pImage, const gcha
 			}
 		}
 		//g_print ("CAIRO_DOCK_ANIMATED_IMAGE -> %d frames\n", pImage->iNbFrames);
+		if (pImage->iNbFrames != 0)
+		{
+			pImage->fDeltaFrame = 1. / pImage->iNbFrames;  // default value
+			gettimeofday (&pImage->time, NULL);
+		}
 	}
 	
 	if (fAlpha < 1 && pImage->pSurface != NULL)
@@ -222,21 +226,50 @@ void cairo_dock_free_image_buffer (CairoDockImageBuffer *pImage)
 	g_free (pImage);
 }
 
+void cairo_dock_image_buffer_next_frame (CairoDockImageBuffer *pImage)
+{
+	if (pImage->iNbFrames == 0)
+		return;
+	struct timeval cur_time = pImage->time;
+	gettimeofday (&pImage->time, NULL);
+	double fElapsedTime = (pImage->time.tv_sec - cur_time.tv_sec) + (pImage->time.tv_usec - cur_time.tv_usec) * 1e-6;
+	double fElapsedFrame = fElapsedTime / pImage->fDeltaFrame;
+	pImage->iCurrentFrame += fElapsedFrame;
+	
+	int n = ((int)pImage->iCurrentFrame);
+	double dn = pImage->iCurrentFrame - n;
+	pImage->iCurrentFrame = (n % pImage->iNbFrames) + dn;
+	//g_print (" + %.2f => %.2f -> %.2f\n", fElapsedTime, fElapsedFrame, pImage->iCurrentFrame);
+}
+
 void cairo_dock_apply_image_buffer_surface_with_offset (CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha)
 {
 	if (cairo_dock_image_buffer_is_animated (pImage))
 	{
+		int iFrameWidth = pImage->iWidth / pImage->iNbFrames;
+		
 		cairo_save (pCairoContext);
 		cairo_translate (pCairoContext, x, y);
-		cairo_rectangle (pCairoContext, 0, 0, pImage->iHeight, pImage->iHeight);
+		cairo_rectangle (pCairoContext, 0, 0, iFrameWidth, pImage->iHeight);
 		cairo_clip (pCairoContext);
-		cairo_set_source_surface (pCairoContext, pImage->pSurface, - pImage->iCurrentFrame * pImage->iHeight, 0.);
-		cairo_paint_with_alpha (pCairoContext, fAlpha);
+		
+		int n = (int) pImage->iCurrentFrame;
+		double dn = pImage->iCurrentFrame - n;
+		
+		cairo_set_source_surface (pCairoContext, pImage->pSurface, - n * iFrameWidth, 0.);
+		cairo_paint_with_alpha (pCairoContext, fAlpha * (1 - dn));
+		
+		int n2 = n + 1;
+		if (n2 >= pImage->iNbFrames)
+			n2  = 0;
+		cairo_set_source_surface (pCairoContext, pImage->pSurface, - n2 * iFrameWidth, 0.);
+		cairo_paint_with_alpha (pCairoContext, fAlpha * dn);
+		
 		cairo_restore (pCairoContext);
 	}
 	else
 	{
-		cairo_set_source_surface (pCairoContext, pImage->pSurface, 0., 0.);
+		cairo_set_source_surface (pCairoContext, pImage->pSurface, x, y);
 		cairo_paint_with_alpha (pCairoContext, fAlpha);
 	}
 }
@@ -247,7 +280,23 @@ void cairo_dock_apply_image_buffer_texture_with_offset (CairoDockImageBuffer *pI
 	if (cairo_dock_image_buffer_is_animated (pImage))
 	{
 		int iFrameWidth = pImage->iWidth / pImage->iNbFrames;
-		_cairo_dock_apply_current_texture_portion_at_size_with_offset ((double)pImage->iCurrentFrame / pImage->iNbFrames, 0,
+		
+		int n = (int) pImage->iCurrentFrame;
+		double dn = pImage->iCurrentFrame - n;
+		
+		_cairo_dock_set_blend_alpha ();
+		
+		_cairo_dock_set_alpha (1. - dn);
+		_cairo_dock_apply_current_texture_portion_at_size_with_offset ((double)n / pImage->iNbFrames, 0,
+			1. / pImage->iNbFrames, 1.,
+			iFrameWidth, pImage->iHeight,
+			x, y);
+		
+		int n2 = n + 1;
+		if (n2 >= pImage->iNbFrames)
+			n2  = 0;
+		_cairo_dock_set_alpha (dn);
+		_cairo_dock_apply_current_texture_portion_at_size_with_offset ((double)n2 / pImage->iNbFrames, 0,
 			1. / pImage->iNbFrames, 1.,
 			iFrameWidth, pImage->iHeight,
 			x, y);
@@ -257,3 +306,64 @@ void cairo_dock_apply_image_buffer_texture_with_offset (CairoDockImageBuffer *pI
 		_cairo_dock_apply_current_texture_at_size_with_offset (pImage->iWidth, pImage->iHeight, x, y);
 	}
 }
+
+
+void cairo_dock_apply_image_buffer_surface_with_offset_and_limit (CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha, int iMaxWidth)
+{
+	cairo_set_source_surface (pCairoContext,
+		pImage->pSurface,
+		x,
+		y);
+	
+	const double a = .75;  // 3/4 plain, 1/4 gradation
+	cairo_pattern_t *pGradationPattern = cairo_pattern_create_linear (x,
+		0.,
+		x + iMaxWidth,
+		0.);
+	cairo_pattern_set_extend (pGradationPattern, CAIRO_EXTEND_NONE);
+	cairo_pattern_add_color_stop_rgba (pGradationPattern,
+		0.,
+		0.,
+		0.,
+		0.,
+		fAlpha);
+	cairo_pattern_add_color_stop_rgba (pGradationPattern,
+		a,
+		0.,
+		0.,
+		0.,
+		fAlpha);
+	cairo_pattern_add_color_stop_rgba (pGradationPattern,
+		1.,
+		0.,
+		0.,
+		0.,
+		0.);
+	cairo_mask (pCairoContext, pGradationPattern);
+	cairo_pattern_destroy (pGradationPattern);
+}
+
+void cairo_dock_apply_image_buffer_texture_with_limit (CairoDockImageBuffer *pImage, double fAlpha, int iMaxWidth)
+{
+	glBindTexture (GL_TEXTURE_2D, pImage->iTexture);
+	
+	int w = iMaxWidth, h = pImage->iHeight;
+	double u0 = 0., u1 = (double) w / pImage->iWidth;
+	glBegin(GL_QUAD_STRIP);
+	
+	double a = .75;  // 3/4 plain, 1/4 gradation
+	a = (double) (floor ((-.5+a)*w)) / w + .5;
+	glColor4f (1., 1., 1., fAlpha);
+	glTexCoord2f(u0, 0); glVertex3f (-.5*w,  .5*h, 0.);  // top left
+	glTexCoord2f(u0, 1); glVertex3f (-.5*w, -.5*h, 0.);  // bottom left
+	
+	glTexCoord2f(u1*a, 0); glVertex3f ((-.5+a)*w,  .5*h, 0.);  // top middle
+	glTexCoord2f(u1*a, 1); glVertex3f ((-.5+a)*w, -.5*h, 0.);  // bottom middle
+	
+	glColor4f (1., 1., 1., 0.);
+	
+	glTexCoord2f(u1, 0); glVertex3f (.5*w,  .5*h, 0.);  // top right
+	glTexCoord2f(u1, 1); glVertex3f (.5*w, -.5*h, 0.);  // bottom right
+	
+	glEnd();
+}
