@@ -38,6 +38,7 @@
 #include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-config.h"
+#include "cairo-dock-icon-manager.h"  // cairo_dock_free_icon
 #include "cairo-dock-module-factory.h"
 #define _MANAGER_DEF_
 #include "cairo-dock-module-manager.h"
@@ -134,8 +135,8 @@ gboolean cairo_dock_register_module (CairoDockModule *pModule)
 		return FALSE;
 	}
 	
-	if (pModule->pVisitCard->cDockVersionOnCompilation == NULL)
-		pModule->pVisitCard->cDockVersionOnCompilation = GLDI_VERSION;
+	if (pModule->cConfFilePath == NULL && pModule->pVisitCard->cConfFileName)
+		pModule->cConfFilePath = g_strdup_printf ("%s/%s", pModule->pVisitCard->cShareDataDir, pModule->pVisitCard->cConfFileName);
 	
 	g_hash_table_insert (s_hModuleTable, (gpointer)pModule->pVisitCard->cModuleName, pModule);
 	
@@ -168,25 +169,16 @@ CairoDockModule * cairo_dock_load_module (const gchar *cSoFilePath)  // cSoFileP
 		g_error_free (erreur);
 		return NULL;
 	}
-	if (pModule == NULL)
+	if (pModule == NULL)  // module not loaded
 		return NULL;
-	g_return_val_if_fail (pModule->pVisitCard != NULL, NULL);
 	
-	g_hash_table_insert (s_hModuleTable, (gpointer)pModule->pVisitCard->cModuleName, pModule);
+	cairo_dock_register_module (pModule);
 	
-	if (cairo_dock_module_is_auto_loaded (pModule))  // c'est un module qui soit ne peut etre activer et/ou desactiver, soit etend un manager; on l'active donc automatiquement.
-	{
-		s_AutoLoadedModules = g_list_prepend (s_AutoLoadedModules, pModule);
-	}
-		
-	cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_REGISTERED, pModule->pVisitCard->cModuleName, TRUE);
 	return pModule;
 }
 
 void cairo_dock_load_modules_in_directory (const gchar *cModuleDirPath, GError **erreur)
 {
-	if (!g_module_supported ())
-		return;
 	if (cModuleDirPath == NULL)
 		cModuleDirPath = GLDI_MODULES_DIR;
 	cd_message ("%s (%s)", __func__, cModuleDirPath);
@@ -274,7 +266,7 @@ void cairo_dock_activate_modules_from_list (gchar **cActiveModuleList)
 	}
 }
 
-static void _cairo_dock_deactivate_one_module (gchar *cModuleName, CairoDockModule *pModule, gpointer data)
+static void _cairo_dock_deactivate_one_module (G_GNUC_UNUSED gchar *cModuleName, CairoDockModule *pModule, G_GNUC_UNUSED gpointer data)
 {
 	if (! cairo_dock_module_is_auto_loaded (pModule))
 		cairo_dock_deactivate_module (pModule);
@@ -390,21 +382,19 @@ void cairo_dock_remove_module_instance (CairoDockModuleInstance *pInstance)
 {
 	cd_message ("%s (%s)", __func__, pInstance->cConfFilePath);
 	g_return_if_fail (pInstance->pModule->pInstancesList != NULL);
-	//\_________________ Si c'est la derniere instance, on desactive le module.
+	//\_________________ If it's the last instance, we disable the module
 	if (pInstance->pModule->pInstancesList->next == NULL)
 	{
 		cairo_dock_deactivate_module_and_unload (pInstance->pModule->pVisitCard->cModuleName);
 		return ;
 	}
 	
-	//\_________________ On efface le fichier de conf de cette instance.
-	cd_debug ("on efface %s", pInstance->cConfFilePath);
+	//\_________________ we remove the .conf file for this instance.
+	cd_debug ("We remove %s", pInstance->cConfFilePath);
 	g_remove (pInstance->cConfFilePath);
 	
-	//\_________________ On supprime cette instance (on le fait maintenant, pour que son fichier de conf n'existe plus lors du 'stop'.
-	gchar *cConfFilePath = pInstance->cConfFilePath;
-	pInstance->cConfFilePath = NULL;
-	CairoDockModule *pModule = pInstance->pModule;
+	//\_________________ We also remove the cConfFilePath (=> this conf file no longer exist during the stop during the stop)
+	g_free (pInstance->cConfFilePath);
 	cairo_dock_deactivate_module_instance_and_unload (pInstance);  // pInstance n'est plus.
 }
 
@@ -525,8 +515,8 @@ void cairo_dock_detach_module_instance_at_position (CairoDockModuleInstance *pIn
 	int iDeskletPositionX = iCenterX - iDeskletWidth/2;
 	int iDeskletPositionY = iCenterY - iDeskletHeight/2;
 	
-	int iRelativePositionX = (iDeskletPositionX + iDeskletWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionX : iDeskletPositionX - g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
-	int iRelativePositionY = (iDeskletPositionY + iDeskletHeight/2 <= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionY : iDeskletPositionY - g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+	// int iRelativePositionX = (iDeskletPositionX + iDeskletWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionX : iDeskletPositionX - g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
+	// int iRelativePositionY = (iDeskletPositionY + iDeskletHeight/2 <= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionY : iDeskletPositionY - g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
 	
 	//\__________________ update the conf file of the applet.
 	g_key_file_set_double (pKeyFile, "Desklet", "x position", iDeskletPositionX);
@@ -591,7 +581,7 @@ void cairo_dock_release_data_slot (CairoDockModuleInstance *pInstance)
 	pInstance->iSlotID = 0;
 }
 
-static gboolean _write_modules (gpointer data)
+static void _write_modules (G_GNUC_UNUSED gpointer data)
 {
 	gchar *cModuleNames = cairo_dock_list_active_modules ();
 	
