@@ -23,13 +23,8 @@
 #include <math.h>
 
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
-#include <cairo.h>
 #include <pango/pango.h>
-#include <librsvg/rsvg.h>
-#include <librsvg/rsvg-cairo.h>
 
 
 #include <X11/extensions/Xrender.h>
@@ -203,8 +198,8 @@ void cairo_dock_fill_gl_path (const CairoDockGLPath *pPath, GLuint iTexture)
 {
 	//\__________________ On active l'antialiasing.
 	glPolygonMode (GL_FRONT, GL_FILL);
-	glEnable (GL_POLYGON_SMOOTH);  // marche po :-(
-	glHint (GL_POLYGON_SMOOTH_HINT, GL_NICEST);
+	//glEnable (GL_POLYGON_SMOOTH);  // makes horrible white lines where the triangles overlaps :-/
+	//glHint (GL_POLYGON_SMOOTH_HINT, GL_NICEST);
 	glEnable (GL_BLEND);  // On active le blend pour l'antialiasing.
 	
 	//\__________________ On mappe la texture dans le cadre.
@@ -250,7 +245,7 @@ void cairo_dock_fill_gl_path (const CairoDockGLPath *pPath, GLuint iTexture)
 		glPopMatrix ();
 		glMatrixMode (GL_MODELVIEW);
 	}
-	glDisable (GL_POLYGON_SMOOTH);
+	//glDisable (GL_POLYGON_SMOOTH);
 	glDisable (GL_BLEND);
 }
 
@@ -267,13 +262,16 @@ const CairoDockGLPath *cairo_dock_generate_rectangle_path (double fFrameWidth, d
 	double h = fFrameHeight / 2;
 	double r = fRadius;
 	
-	int ddeg = (fRadius < 5 ? 6 : 3);
-	int iNbPoins1Round = 90/15;
+	int iNbPoins1Round = 90/10;
 	if (pPath == NULL)
-		pPath = cairo_dock_new_gl_path ((iNbPoins1Round+1)*4+1, w+r, h, fTotalWidth, fTotalHeight);  // on commence au coin haut droit pour avoir une bonne triangulation du polygone, et en raisonnant par rapport au centre du rectangle.
+	{
+		pPath = cairo_dock_new_gl_path ((iNbPoins1Round+1)*4+1, w+r, h, fTotalWidth, fTotalHeight);  // on commence au centre droit pour avoir une bonne triangulation du polygone, et en raisonnant par rapport au centre du rectangle.
+		///pPath = cairo_dock_new_gl_path ((iNbPoins1Round+1)*4+1, 0, 0, fTotalWidth, fTotalHeight);  // on commence au centre pour avoir une bonne triangulation
+	}
 	else
 	{
 		cairo_dock_gl_path_move_to (pPath, w+r, h);
+		///cairo_dock_gl_path_move_to (pPath, 0, 0);
 		cairo_dock_gl_path_set_extent (pPath, fTotalWidth, fTotalHeight);
 	}
 	//cairo_dock_gl_path_move_to (pPath, 0., h+r);
@@ -429,8 +427,6 @@ const CairoDockGLPath *cairo_dock_generate_string_path_opengl (CairoDock *pDock,
 		cairo_dock_gl_path_set_extent (pPath, pDock->container.iHeight, pDock->container.iWidth);
 	
 	// on parcourt les icones.
-	double t;
-	int i, n=0;
 	do
 	{
 		// l'icone courante, la suivante, et celle d'apres.
@@ -467,7 +463,7 @@ const CairoDockGLPath *cairo_dock_generate_string_path_opengl (CairoDock *pDock,
 		if (next_ic == pFirstDrawnElement && ! bIsLoop)
 			break ;
 	}
-	while (ic != pFirstDrawnElement && n < 100*NB_VERTEX_PER_ICON_PAIR);
+	while (ic != pFirstDrawnElement);
 	
 	return pPath;
 }
