@@ -25,8 +25,26 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include <cairo.h>
+
+/*
+ * We include rsvg stuff here, because it's such a mess that it's better to not
+ *  duplicate that.
+ * We need to include glib.h before because it uses G_BEGIN_DECL without
+ * including glib first! (bug fixed with the version 2.36.2)
+ * Note: with this 2.36.2 version, rsvg-cairo.h and librsvg-features.h are
+ *  included in rsvg.h and including these header files directly are now
+ *  deprecated. But we need 'librsvg-features.h' to use LIBRSVG_CHECK_VERSION
+ *  macro in order to know if we can include (or not) librsvg-cairo.h...
+ *   Yeah, a bit strange :)
+ */
 #include <librsvg/rsvg.h>
+#ifndef LIBRSVG_CHECK_VERSION
+#include <librsvg/librsvg-features.h>
+#endif
+#if !LIBRSVG_CHECK_VERSION (2, 36, 2)
 #include <librsvg/rsvg-cairo.h>
+#endif
+
 #include <glib/gi18n.h>
 //#include <X11/extensions/Xdamage.h>
 
@@ -322,7 +340,7 @@ when defining your applet in the \ref CD_APPLET_DEFINE_BEGIN/\ref CD_APPLET_DEFI
  * 
  * \subsection render_container How can I draw anywhere on the dock, not only on my icon ?
  * 
- * Say you want to draw directly on your container, like <i>CairoPenguin</i> or <i>ShowMouse</i> do. This can be achieved easily by registering to the \ref NOTIFICATION_RENDER_DOCK or \ref NOTIFICATION_RENDER_DESKLET notifications. You will then be notified eash time a Dock or a Desklet is drawn. Register AFTER so that you will draw after the view.
+ * Say you want to draw directly on your container, like <i>CairoPenguin</i> or <i>ShowMouse</i> do. This can be achieved easily by registering to the \ref NOTIFICATION_RENDER notification. You will then be notified eash time a Dock or a Desklet is drawn. Register AFTER so that you will draw after the view.
  * 
  * 
  */
