@@ -19,8 +19,6 @@
 
 #include <string.h>
 #include <math.h>
-#include <librsvg/rsvg.h>
-#include <librsvg/rsvg-cairo.h>
 #include <pango/pango.h>
 
 #include "cairo-dock-log.h"
@@ -29,6 +27,7 @@
 #include "cairo-dock-container.h"
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-X-manager.h"
+#include "cairo-dock-icon-manager.h"  // cairo_dock_search_icon_s_path
 #include "cairo-dock-surface-factory.h"
 
 extern CairoContainer *g_pPrimaryContainer;
@@ -102,10 +101,10 @@ void cairo_dock_calculate_constrainted_size (double *fImageWidth, double *fImage
 			{
 				iWidthConstraint = *fImageWidth / *fImageHeight * iHeightConstraint;
 			}
-			else if (*fImageWidth > 2 * *fImageHeight)  // if we're pretty sure this image is an animated one, try to be smart, to handle the case of non-square frames.
+			else if (*fImageWidth > 2 * *fImageHeight)  // if we're confident this image is an animated one, try to be smart, to handle the case of non-square frames.
 			{
 				// assume we have wide frames => w > h
-				int w = *fImageHeight + 1, h = *fImageHeight;
+				int w = *fImageHeight + 1;
 				do
 				{
 					if ((int)*fImageWidth % w == 0)
@@ -620,14 +619,14 @@ cairo_surface_t *cairo_dock_create_surface_from_pattern (const gchar *cImageFile
 	if (cImageFile != NULL)
 	{
 		gchar *cImagePath = cairo_dock_search_image_s_path (cImageFile);
-		double fImageWidth, fImageHeight;
+		double w, h;
 		cairo_surface_t *pPatternSurface = cairo_dock_create_surface_from_image (cImagePath,
 			1.,
-			0,  // pas de contrainte sur
-			0,  // la taille du motif initialement.
-			CAIRO_DOCK_FILL_SPACE,
-			&fImageWidth,
-			&fImageHeight,
+			0,  // no constraint on the width of the pattern => the pattern will repeat on the width
+			fImageHeight,  // however, we want to see all the height of the pattern with no repetition => constraint on the height
+			CAIRO_DOCK_FILL_SPACE | CAIRO_DOCK_KEEP_RATIO,
+			&w,
+			&h,
 			NULL, NULL);
 		g_free (cImagePath);
 		if (pPatternSurface == NULL)
@@ -918,7 +917,6 @@ cairo_surface_t *cairo_dock_create_surface_from_text_full (const gchar *cText, C
 		if (w > iMaxLineWidth)  // le texte est trop long.
 		{
 			// on decoupe le texte en lignes et on limite chaque ligne trop longue.
-			gchar *sp, *last_sp=NULL;
 			gchar **cLines = g_strsplit (cText, "\n", -1);
 			gchar *cLine;
 			int i;
